Getting started
===============


Installation
============

You can use the Python package manager pip to install pyearth:

    pip install pyearth

You can also use the Conda package manager to install pyearth:

    conda install -c conda-forge pyearth    

Usage
=====

To use functions from pyearth, you need to import the package or the functions directly:

    import pyearth

    from pyearth.visual.color.create_diverge_rgb_color_hex import create_diverge_rgb_color_hex


